// Example 03-20 from "Getting Started with Processing" 
// by Reas & Fry. O'Reilly / Make 2010

// The example was changed to fit into functions: drawLeftCreature and drawRightCreature

// Both functions can be called in three different ways:
// - without parameters --> will place the left or right creature into a fixed position on screen
// - with x and y position parameters --> will place the creature into that position on screen
// - with x and y position and a scaling parameter --> will place a scaled creature into that position on screen


void setup() {
  size(480, 120);
  smooth();

  // drawing creatures at fixed positions
  drawLeftCreature();
  drawRightCreature();

  // drawing creatures at variable positions
  drawLeftCreature(20, 20);
  drawRightCreature(20, 20);

  // drawing creatures at variable positions and scale
  drawLeftCreature(40, 40, 2.0);
  drawRightCreature(40, 40, 0.5);
}

// draw left creature at fixed position
void drawLeftCreature() {
  // body
  fill(255);
  beginShape();
  vertex(50, 120);
  vertex(100, 90);
  vertex(110, 60);
  vertex(80, 20);
  vertex(210, 60);
  vertex(160, 80);
  vertex(200, 90);
  vertex(140, 100);
  vertex(130, 120);
  endShape();

  // eye
  fill(0);
  ellipse(155, 60, 8, 8);
}

// draw right creature at fixed position
void drawRightCreature() {
  // body
  fill(255);
  beginShape();
  vertex(370, 120);
  vertex(360, 90);
  vertex(290, 80);
  vertex(340, 70);
  vertex(280, 50);
  vertex(420, 10);
  vertex(390, 50);
  vertex(410, 90);
  vertex(460, 120);
  endShape();
  
  // eye
  fill(0);
  ellipse(345, 50, 10, 10);
}

// draw left creature at variable position (with translate)
void drawLeftCreature(int x, int y) {
  // move shape
  pushMatrix();
  translate(x, y);
  
  // body
  fill(255);
  beginShape();
  vertex(50, 120);
  vertex(100, 90);
  vertex(110, 60);
  vertex(80, 20);
  vertex(210, 60);
  vertex(160, 80);
  vertex(200, 90);
  vertex(140, 100);
  vertex(130, 120);
  endShape();

  // eye
  fill(0);
  ellipse(155, 60, 8, 8);
  
  // reset moving
  popMatrix();
}

// draw right creature at variable position (with translate)
void drawRightCreature(int x, int y) {
  // move shape
  pushMatrix();
  translate(x, y);
  
  // body
  fill(255);
  beginShape();
  vertex(370, 120);
  vertex(360, 90);
  vertex(290, 80);
  vertex(340, 70);
  vertex(280, 50);
  vertex(420, 10);
  vertex(390, 50);
  vertex(410, 90);
  vertex(460, 120);
  endShape();
  
  // eye
  fill(0);
  ellipse(345, 50, 10, 10);

  // reset moving
  popMatrix();
}
// draw left creature at variable position (with translate)
void drawLeftCreature(int x, int y, float scaling) {
  // move shape
  pushMatrix();
  translate(x, y);
  scale(scaling);
  
  // body
  fill(255);
  beginShape();
  vertex(50, 120);
  vertex(100, 90);
  vertex(110, 60);
  vertex(80, 20);
  vertex(210, 60);
  vertex(160, 80);
  vertex(200, 90);
  vertex(140, 100);
  vertex(130, 120);
  endShape();

  // eye
  fill(0);
  ellipse(155, 60, 8, 8);
  
  // reset moving
  popMatrix();
}

// draw right creature at variable position (with translate)
void drawRightCreature(int x, int y, float scaling) {
  // move shape
  pushMatrix();
  translate(x, y);
  scale(scaling);
  
  // body
  fill(255);
  beginShape();
  vertex(370, 120);
  vertex(360, 90);
  vertex(290, 80);
  vertex(340, 70);
  vertex(280, 50);
  vertex(420, 10);
  vertex(390, 50);
  vertex(410, 90);
  vertex(460, 120);
  endShape();
  
  // eye
  fill(0);
  ellipse(345, 50, 10, 10);

  // reset moving
  popMatrix();
}

